@@ -1,7 +1,7 @@
 
 /*
- *	$RCSfile: mail_reader.c,v $	$Revision: 1.4 $ 
- *	$Date: 1996/12/17 22:53:46 $
+ *	$RCSfile: mail_reader.c,v $	$Revision: 1.5 $ 
+ *	$Date: 1997/03/09 16:27:20 $
  *
  *	(c) Copyright 1993-1996 by Mark Grant, and by other
  *	authors as appropriate. All right reserved.
@@ -565,6 +565,9 @@ MESSAGE	*m;
 	}
 }
 
+/* I think all of these should use header_date rather than date, but I
+   don't have the machines available to test that. */
+
 static	time_t	get_time (m)
 
 MESSAGE	*m;
@@ -612,18 +615,19 @@ MESSAGE	*m;
 #else
 #ifdef linux
 #define getdate(x) (parsedate((x),NULL))
+	if (!m->header_date)
+		return 0;
 	tmp = getdate (m->header_date);
 	t = localtime (&tmp);
 #else
 	t = (struct tm *)getdate (m->date);
-
+#endif
 	if (t)
 		return mktime (t);
 	else
 		return 0;
 #endif
 #endif
-#endif
 }
 
 MESSAGE	*message_from_message(m)
