@@ -1,16 +1,17 @@
 
 /*
- *	@(#)windows.h	1.2 8/10/95
+ *	$RCSfile: windows.h,v $	$Revision: 1.1 $ 
+ *	$Date: 1997/03/09 16:27:56 $
  *
- *	(c) Copyright 1993-1995 by Mark Grant, and by other
+ *	(c) Copyright 1993-1996 by Mark Grant, and by other
  *	authors as appropriate. All right reserved.
  *
  *	The authors assume no liability for damages resulting from the 
  *	use of this software, even if the damage results from defects in
  *	this software. No warranty is expressed or implied.
  *
- *	This software is being distributed under the GNU Public Licence,
- *	see the file COPYING for more details.
+ *	This software is distributed under the GNU Public Licence, see
+ *	the file COPYING for more details.
  *
  *			- Mark Grant (mark@unicorn.com) 29/6/94
  *
@@ -37,12 +38,32 @@ typedef struct _compose_window {
 	int	in_use;
 	
 } COMPOSE_WINDOW;
+
+typedef struct _display_window {
+
+	struct	_display_window	*next, *prev;
+
+	Frame	display_frame;
+	Panel	display_panel;
+
+	Panel_item	addkey_item;
+	Panel_item	sender_item;
+	Panel_item	date_item;
+	Panel_item	decode_item;
+	Textsw	sig_window;
+	Textsw	body_window;
+
+	int	number;
+
+} DISPLAY_WINDOW;
 #else
 typedef	int	COMPOSE_WINDOW;
+typedef int	DISPLAY_WINDOW;
 #endif
 
 /* Declare function */
 
 COMPOSE_WINDOW	*x_setup_send_window ();
 COMPOSE_WINDOW	*setup_send_window ();
+DISPLAY_WINDOW	*create_display_window ();
 
